@@ -10,6 +10,7 @@
 #include <glib-object.h>
 
 #include <libebackend/libebackend.h>
+#include <libecal/libecal.h>
 #include <json-glib/json-glib.h>
 #include <libsoup/soup.h>
 
@@ -50,6 +51,13 @@ typedef enum _EM365ApiVersion {
 	E_M365_API_BETA
 } EM365ApiVersion;
 
+typedef enum {
+	E_M365_ERROR_ID_MALFORMED
+} EM365Error;
+
+#define	E_M365_ERROR e_m365_error_quark ()
+GQuark		e_m365_error_quark		(void) G_GNUC_CONST;
+
 typedef struct _EM365Connection EM365Connection;
 typedef struct _EM365ConnectionClass EM365ConnectionClass;
 typedef struct _EM365ConnectionPrivate EM365ConnectionPrivate;
@@ -84,7 +92,13 @@ void		e_m365_connection_util_set_message_status_code
 						 gint status_code);
 gint		e_m365_connection_util_get_message_status_code
 						(SoupMessage *message);
-
+gboolean	e_m365_connection_util_read_raw_data_cb
+						(EM365Connection *cnc,
+						 SoupMessage *message,
+						 GInputStream *raw_data_stream,
+						 gpointer user_data, /* CamelStream * */
+						 GCancellable *cancellable,
+						 GError **error);
 GType		e_m365_connection_get_type	(void) G_GNUC_CONST;
 
 EM365Connection *
@@ -487,6 +501,7 @@ gboolean	e_m365_connection_list_events_sync
 						 const gchar *calendar_id,
 						 const gchar *prefer_outlook_timezone, /* nullable - then UTC, otherwise that zone for the returned times */
 						 const gchar *select, /* nullable - properties to select */
+						 const gchar *filter, /* nullable - filter which events to list */
 						 GSList **out_events, /* EM365Event * - the returned event objects */
 						 GCancellable *cancellable,
 						 GError **error);
@@ -530,6 +545,16 @@ gboolean	e_m365_connection_get_events_sync
 						 GSList **out_events, /* EM365Event *, in the same order as event_ids; can return partial list */
 						 GCancellable *cancellable,
 						 GError **error);
+gboolean	e_m365_connection_get_event_instance_id_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable, then the default group is used */
+						 const gchar *calendar_id,
+						 const gchar *event_id,
+						 ICalTime *instance_time,
+						 gchar **out_instance_id,
+						 GCancellable *cancellable,
+						 GError **error);
 gboolean	e_m365_connection_update_event_sync
 						(EM365Connection *cnc,
 						 const gchar *user_override, /* for which user, NULL to use the account user */
@@ -558,6 +583,15 @@ gboolean	e_m365_connection_response_event_sync
 						 gboolean send_response,
 						 GCancellable *cancellable,
 						 GError **error);
+gboolean	e_m365_connection_cancel_event_sync
+						(EM365Connection *cnc,
+						 const gchar *user_override, /* for which user, NULL to use the account user */
+						 const gchar *group_id, /* nullable, then the default group is used */
+						 const gchar *calendar_id,
+						 const gchar *event_id,
+						 const gchar *comment,
+						 GCancellable *cancellable,
+						 GError **error);
 gboolean	e_m365_connection_dismiss_reminder_sync
 						(EM365Connection *cnc,
 						 const gchar *user_override, /* for which user, NULL to use the account user */
@@ -666,6 +700,7 @@ gboolean	e_m365_connection_list_tasks_sync
 						 const gchar *task_list_id,
 						 const gchar *prefer_outlook_timezone, /* nullable - then UTC, otherwise that zone for the returned times */
 						 const gchar *select, /* nullable - properties to select */
+						 const gchar *filter, /* nullable - filter which tasks to list */
 						 GSList **out_tasks, /* EM365Task * - the returned task objects */
 						 GCancellable *cancellable,
 						 GError **error);
